﻿// --------------------------------------------------------------------------------------
//
// FTS1.cs                                                        Ulrich Müller  25.02.08
//                                                                PCS1700 C# 2005 Express
// Mobile Robots II : Fahrerloses Transportsystem, Steuerung der Einzelschritte über Funk
//   Basis ist die Assembly FishFace2005.DLL
//
// --------------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using FishFace40;

namespace FTS1 {
  public partial class FTS1 : Form {
    FishFace ft = new FishFace();

    const Out mRechts     = Out.M1;
    const Out mLinks      = Out.M2;
    const Inp iImpulseR   = Inp.I1;
    const Inp iImpulseL   = Inp.I2;
    const Dir dVor        = Dir.Links;
    const Dir dRuck       = Dir.Rechts;

    const Inp iRechtsRaus = Inp.I3;
    const Inp iLinksRaus  = Inp.I4;

    const Out mHupe       = Out.M3;

    const Out mHub        = Out.M4;
    const Inp iHubOben    = Inp.I5;
    const Inp iHubUnten   = Inp.I6;
    const Dir dAb         = Dir.Links;
    const Dir dAuf        = Dir.Rechts;

    #region --- Programm-Kontrolle ---
    public FTS1() {
      InitializeComponent();
    }

    private void cmdAction_Click(object sender, EventArgs e) {
      // --- Open erstes ROBO an USB oder Intelligent Interface an COM
      //     während des Ablaufs von Action() gesperrt ---------------
      try {
        if (cboPortName.SelectedIndex == 0)
          ft.OpenInterface(IFTypen.ftROBO_first_USB, 0);
        else ft.OpenInterface(IFTypen.ftIntelligent_IF, cboPortName.SelectedIndex, 5);
        cmdAction.Enabled = false;
        lblStatus.Text = "--- Interface läuft ---";
        lblHinweis.Text = "--- Abbruch : ESC-Taste ---";
        cmdEnde.Text = "&ENDE";
        ft.ClearMotors();
        pnlCommands.Enabled = true;
      }
      catch (FishFaceException eft) {
        MessageBox.Show(eft.Message, this.Text,
          MessageBoxButtons.OK, MessageBoxIcon.Stop);
        ft.CloseInterface();
      }
    }

    private void cmdEnde_Click(object sender, EventArgs e) {
      // --- Programmende nur, wenn Action nicht läuft ---
      ft.CloseInterface();
      this.Close(); 
    }

    private void formLoad(object sender, EventArgs e) {
      // --- Default-Interface : Erstes ROBO Interface an USB ----
      cboPortName.SelectedIndex = 0;
    }
    #endregion

    private void Heben() {
      ft.SetMotor(mHub, dAuf);
      ft.WaitForInput(iHubOben);
      ft.SetMotor(mHub, Dir.Aus);
    }
    private void Senken() {
      ft.SetMotor(mHub, dAb);
      ft.WaitForInput(iHubUnten);
      ft.SetMotor(mHub, Dir.Aus);
    }
    private void Rueck(int Schritte) {
      ft.SetMotor(mRechts, dRuck, Speed.Half);
      ft.SetMotor(mLinks, dRuck, Speed.Half);
      ft.WaitForChange(iImpulseR, Schritte);
      ft.SetMotor(mRechts, Dir.Aus);
      ft.SetMotor(mLinks, Dir.Aus);
    }
    private void Vor(int Schritte) {
      ft.SetMotor(mRechts, dVor, Speed.Half);
      ft.SetMotor(mLinks, dVor, Speed.Half);
      ft.WaitForChange(iImpulseR, Schritte);
      ft.SetMotor(mRechts, Dir.Aus);
      ft.SetMotor(mLinks, Dir.Aus);
    }
    private void Hupen(int nrHupen) {
      for ( int i = 0; i < nrHupen; i++) {
        ft.SetMotor(mHupe, Dir.Ein);
        ft.Pause(333);
        ft.SetMotor(mHupe, Dir.Aus);
        ft.Pause(222);
      }
    }
    private void SpurFahren() {
      do {
        ft.SetMotor(mRechts, dVor, Speed.Half);
        ft.SetMotor(mLinks, dVor, Speed.Half);
        if (ft.GetInput(iRechtsRaus)) ft.SetMotor(mLinks, dRuck, Speed.Half);
        else if (ft.GetInput(iLinksRaus)) ft.SetMotor(mRechts, dRuck, Speed.Half);
        ft.Pause(12);
      } while ((ft.GetInputs() & 0xC) != 0xC && !ft.Finish());
      ft.SetMotor(mRechts, Dir.Aus);
      ft.SetMotor(mLinks, Dir.Aus);
      Hupen(2);
    }
    private void Drehen() {
      ft.SetMotor(mRechts, dVor, Speed.Half);
      ft.SetMotor(mLinks, dRuck, Speed.Half);
      do {
        Application.DoEvents(); ft.Pause(12);
      } while ((ft.GetInputs() & 0xC) == 0xC && !ft.Finish());
      ft.SetMotor(mRechts, Dir.Aus);
      ft.SetMotor(mLinks, Dir.Aus);
    }
    private void Abladen() { 
      Vor(8);
      Senken();
      Rueck(7);
    }
    private void Aufladen() {
      Vor(8);
      Heben();
      Rueck(7);
    }

    private void cmdSpur_Click(object sender, EventArgs e) {
      lblStatus.Text = "SpurFahren";
      SpurFahren();
      lblStatus.Text = "Bereit für neue Befehle";
    }

    private void cmdAbladen_Click(object sender, EventArgs e) {
      lblStatus.Text = "Abladen";
      Abladen();
      lblStatus.Text = "Bereit für neue Befehle";
    }

    private void cmdAufladen_Click(object sender, EventArgs e) {
      lblStatus.Text = "Aufladen";
      Aufladen();
      lblStatus.Text = "Bereit für neue Befehle";
    }

    private void cmdDrehen_Click(object sender, EventArgs e) {
      lblStatus.Text = "Drehen";
      Drehen();
      lblStatus.Text = "Bereit für neue Befehle";
    }

    private void cmdHolen_Click(object sender, EventArgs e) {
      lblStatus.Text = "Senken";
      Senken();
      lblStatus.Text = "SpurFahren";
      SpurFahren();
      lblStatus.Text = "Aufladen()";
      Aufladen();
      lblStatus.Text = "Drehen";
      Drehen();
      lblStatus.Text = "SpurFahren";
      SpurFahren();
      lblStatus.Text = "Abladen";
      Abladen();
      lblStatus.Text = "Bereit für neue Befehle";
    }

    private void cmdBringen_Click(object sender, EventArgs e) {
      lblStatus.Text = "Anfahren";
      SpurFahren();
      lblStatus.Text = "Aufladen";
      Aufladen();
      lblStatus.Text = "Drehen";
      Drehen();
      lblStatus.Text = "SpurFahren";
      SpurFahren();
      lblStatus.Text = "Abladen()";
      Abladen();
      lblStatus.Text = "Drehen";
      Drehen();
      lblStatus.Text = "SpurFahren";
      SpurFahren();
      lblStatus.Text = "Bereit für neue Befehle";
    }
  }
}